@@ -40,13 +40,15 @@ setMethod("simulate",signature(object="BINOMresponse"),
 			pr <- predict(object)[times,]
 		}
 		nt <- nrow(pr)
+		n <- rowSums(object@y)
 		if(NCOL(object@y) == 2) {
-			response <- rbinom(nt*nsim,size=object@y[,2],prob=pr)
+			response <- rbinom(nt*nsim,size=n,prob=pr)
+ 			response <- cbind(response,n-response)
 		} else {
 			response <- rbinom(nt*nsim,size=1,prob=pr)
 		}
 		#if(nsim > 1) response <- matrix(response,ncol=nsim)
-		response <- as.matrix(response)
+ 		response <- as.matrix(response)
 		return(response)
 	}
 )
